Index: src/ic/x87/handler-compiler-x87.cc |
diff --git a/src/ic/x87/handler-compiler-x87.cc b/src/ic/x87/handler-compiler-x87.cc |
index 1b25f063473f6d8480232869c58540ac7af281ba..e1eea1af7a55f8fb32fe5ac23be36d2ff86393db 100644 |
--- a/src/ic/x87/handler-compiler-x87.cc |
+++ b/src/ic/x87/handler-compiler-x87.cc |
@@ -158,7 +158,7 @@ void PropertyHandlerCompiler::GenerateApiAccessorCall( |
// Stack now matches JSFunction abi. |
DCHECK(optimization.is_simple_api_call()); |
// Abi for CallApiFunctionStub. |
Register callee = edi; |
Register data = ebx; |
Register holder = ecx; |
@@ -220,7 +220,7 @@ void PropertyHandlerCompiler::GenerateApiAccessorCall( |
__ mov(api_function_address, Immediate(function_address)); |
// Jump to stub. |
- CallApiAccessorStub stub(isolate, is_store, call_data_undefined, |
+ CallApiCallbackStub stub(isolate, is_store, call_data_undefined, |
!optimization.is_constant_call()); |
__ TailCallStub(&stub); |
} |
@@ -158,7 +158,7 @@ void PropertyHandlerCompiler::GenerateApiAccessorCall( |
// Stack now matches JSFunction abi. |
DCHECK(optimization.is_simple_api_call()); |
- // Abi for CallApiFunctionStub. |
+ // Abi for CallApiCallbackStub. |
Register callee = edi; |
Register data = ebx; |